@@ -144,6 +144,12 @@ class AppHandler(object):
         from rattail.time import make_utc
         return make_utc(*args, **kwargs)
 
+    def today(self, **kwargs):
+        """
+        Return the current date.
+        """
+        return self.localtime().date()
+
     def load_entry_points(self, group, **kwargs): # pragma: no cover
         warnings.warn("method is deprecated, please use "
                       "util.load_entry_points() function directly",
@@ -232,12 +238,33 @@ class AppHandler(object):
             session.add(setting)
         setting.value = value
 
+        # invalidate beaker config cache for this setting, if applicable
+        self.config.beaker_invalidate_setting(name)
+
     def delete_setting(self, session, name, **kwargs):
         model = self.model
         setting = session.query(model.Setting).get(name)
         if setting:
             session.delete(setting)
 
+    def touch_object(self, session, obj):
+        """
+        Mark the given object as having been changed, such that the
+        datasync will pick it up and propagate the object to other
+        nodes.
+
+        Note that this is *minimal* logic; only the given object will
+        be "touched" in this way, i.e. no related records will be
+        touched.  So if those also need it, you must call this method
+        for each related object separately.
+        """
+        model = self.model
+        change = model.Change()
+        change.class_name = obj.__class__.__name__
+        change.instance_uuid = obj.uuid
+        change = session.merge(change)
+        change.deleted = False
+
     def get_active_stores(self, session, **kwargs):
         """
         Returns the list of "active" stores.  A store is considered
@@ -825,14 +852,17 @@ class AppHandler(object):
         """
         from rattail.db import Session
 
-        # always try to set default continuum user if possible
+        session = Session(**kwargs)
+
+        # try to set continuum user unless kwargs already set it
         if 'continuum_user' not in kwargs:
             if not user:
-                user = self.config.get('rattail', 'runas.default')
+                user = self.config.get('rattail', 'runas.default',
+                                       session=session)
             if user:
-                kwargs['continuum_user'] = user
+                session.set_continuum_user(user)
 
-        return Session(**kwargs)
+        return session
 
     def cache_model(self, session, model, **kwargs):
         """
@@ -854,9 +884,11 @@ class AppHandler(object):
             os.mkdir(appdir)
 
         folders = [
+            'cache',
             'data',
             os.path.join('data', 'uploads'),
             'log',
+            # TODO: deprecate / remove this
             'sessions',
             'work',
         ]
@@ -935,22 +967,29 @@ class AppHandler(object):
                                   output_path=output_path)
         return output_path
 
-    def find_config_template(self, name):
+    def get_all_config_templates(self, **kwargs):
+        templates = OrderedDict()
         template_paths = self.config.getlist('rattail.config', 'templates',
                                              default=['rattail:data/config'])
         for template_path in template_paths:
+            template_path = resource_path(template_path)
+            for filename in os.listdir(template_path):
 
-            # prefer mako templates
-            path = resource_path('{}/{}.conf.mako'.format(template_path.rstrip('/'),
-                                                          name))
-            if os.path.exists(path):
-                return path
+                if filename.endswith('.conf.mako'):
+                    name = filename[:-len('.conf.mako')]
+                    templates.setdefault(name, os.path.join(template_path, filename))
 
-            # but plain config works too
-            path = resource_path('{}/{}.conf'.format(template_path.rstrip('/'),
-                                                     name))
-            if os.path.exists(path):
-                return path
+                elif filename.endswith('.conf'):
+                    name = filename[:-len('.conf')]
+                    templates.setdefault(name, os.path.join(template_path, filename))
+
+        templates = OrderedDict([(key, templates[key])
+                                 for key in sorted(templates)])
+        return templates
+
+    def find_config_template(self, name, **kwargs):
+        templates = self.get_all_config_templates()
+        return templates.get(name)
 
     def make_temp_dir(self, **kwargs):
         """
