@@ -70,23 +70,31 @@ class VendorCatalogHandler(BatchHandler):
         return True
 
     def setup(self, batch, progress=None):
+        model = self.model
+
+        # TODO: deprecate / remove this
         self.vendor = batch.vendor
-        self.products = {'upc': {}, 'vendor_code': {}}
-        session = self.app.get_session(batch)
-        products = session.query(model.Product)\
-                          .options(orm.joinedload(model.Product.brand))\
-                          .options(orm.joinedload(model.Product.costs))
 
-        def cache(product, i):
-            if product.upc:
-                self.products['upc'][product.upc] = product
-            cost = product.cost_for_vendor(self.vendor)
-            product.vendor_cost = cost
-            if cost and cost.code:
-                self.products['vendor_code'][cost.code] = product
+        # maybe pre-cache all products
+        if batch.get_param('cache_products'):
 
-        assert self.progress_loop(cache, products.all(), progress,
-                                  message="Caching products by UPC and vendor code")
+            self.products = {'upc': {}, 'vendor_code': {}}
+            session = self.app.get_session(batch)
+            products = session.query(model.Product)\
+                              .options(orm.joinedload(model.Product.brand))\
+                              .options(orm.joinedload(model.Product.costs))\
+                              .all()
+
+            def cache(product, i):
+                if product.upc:
+                    self.products['upc'][product.upc] = product
+                cost = product.cost_for_vendor(batch.vendor)
+                product.vendor_cost = cost
+                if cost and cost.code:
+                    self.products['vendor_code'][cost.code] = product
+
+            self.progress_loop(cache, products, progress,
+                               message="Caching products by UPC and vendor code")
 
     setup_populate = setup
     setup_refresh = setup
@@ -204,9 +212,8 @@ class VendorCatalogHandler(BatchHandler):
             if hasattr(self, 'products'):
                 product = self.products['vendor_code'].get(row.vendor_code)
             else:
-                product = products_handler.locate_product_for_entry(
-                    session, row.vendor_code, product_key='ignore',
-                    lookup_vendor_code=True, vendor=row.batch.vendor)
+                product = products_handler.locate_product_for_vendor_code(
+                    session, row.vendor_code, vendor=row.batch.vendor)
 
         return product
 
