@@ -129,7 +129,6 @@ class RattailConfig(object):
         # Attempt to detect lack of SQLAlchemy libraries etc.  This allows us
         # to avoid installing those on a machine which will not need to access
         # a database etc.
-        self._session_factory = None
         if self.usedb:
             try:
                 from rattail.db import Session
@@ -139,12 +138,40 @@ class RattailConfig(object):
                             exc_info=True)
                 self.usedeb = False
                 self.preferdb = False
-            else:
-                self._session_factory = lambda: (Session(), True)
 
         # this is always false, unless/until it becomes true
         self.versioning_has_been_enabled = False
 
+        # should we use beaker caching?
+        self.beaker_caching = self.getbool('rattail.config', 'beaker_cache.enabled',
+                                           usedb=False, default=False)
+        if self.beaker_caching:
+            from beaker.cache import CacheManager
+            from beaker.util import parse_cache_config_options
+
+            options = {
+                'cache.type': self.get(
+                    'rattail.config', 'beaker_cache.type',
+                    usedb=False,
+                    default='file'),
+                'cache.data_dir': self.get(
+                    'rattail.config', 'beaker_cache.data_dir',
+                    usedb=False,
+                    default=os.path.join(self.appdir(), 'cache', 'config', 'data')),
+                'cache.lock_dir': self.get(
+                    'rattail.config', 'beaker_cache.lock_dir',
+                    usedb=False,
+                    default=os.path.join(self.appdir(), 'cache', 'config', 'lock')),
+            }
+
+            self.beaker_cache_manager = CacheManager(
+                **parse_cache_config_options(options))
+
+            self.beaker_config_cache = self.beaker_cache_manager.get_cache(
+                'rattail.config',
+                type='file',    # TODO: (why) must we declare this?
+                expire=3600)
+
     def read_file(self, path, recurse=True, require=False):
         """
         Read in config from the given file.
@@ -297,27 +324,64 @@ class RattailConfig(object):
         """
         Retrieve a config value from database settings table.
         """
-        from rattail.db import api
+        app = self.get_app()
+        name = '{}.{}'.format(section, option)
+
+        if self.beaker_caching:
+            return self._getdb_beaker(section, option)
 
         close = False
-        if session is None:
-            session, close = self._session_factory()
-        value = api.get_setting(session, '{}.{}'.format(section, option))
+        if not session:
+            # nb. avoid continuum user lookup
+            session = app.make_session(continuum_user=None)
+            close = True
+
+        value = app.get_setting(session, name)
+
         if close:
             session.close()
+
         return value
 
+    def _getdb_beaker(self, section, option):
+        """
+        Retrieve a config value from database settings table.
+        """
+        app = self.get_app()
+        name = '{}.{}'.format(section, option)
+
+        def get_value():
+            # nb. avoid continuum user lookup
+            session = app.make_session(continuum_user=None)
+            value = app.get_setting(session, name)
+            session.close()
+            return value
+
+        return self.beaker_config_cache.get(key=name, createfunc=get_value)
+
+    def beaker_invalidate_setting(self, name):
+        if not self.beaker_caching:
+            return
+
+        # tell beaker to remove the cached value for this setting
+        self.beaker_config_cache.remove_value(key=name)
+
     def setdb(self, section, option, value, session=None):
         """
         Set a config value in the database settings table.  Note that the
         ``value`` arg should be a Unicode object.
         """
-        from rattail.db import api
+        app = self.get_app()
 
         close = False
-        if session is None:
-            session, close = self._session_factory()
-        api.save_setting(session, '{}.{}'.format(section, option), value)
+        if not session:
+            # nb. avoid continuum user lookup
+            session = app.make_session(continuum_user=None)
+            close = True
+
+        name = '{}.{}'.format(section, option)
+        app.save_setting(session, name, value)
+
         if close:
             session.commit()
             session.close()
@@ -410,7 +474,7 @@ class RattailConfig(object):
         if necessary.
         """
         if not hasattr(self, 'app'):
-            spec = self.get('rattail', 'app.handler',
+            spec = self.get('rattail', 'app.handler', usedb=False,
                             default='rattail.app:AppHandler')
             factory = load_object(spec)
             self.app = factory(self)
@@ -477,6 +541,7 @@ class RattailConfig(object):
         Returns path to the 'app' dir, if known.
         """
         get = self.require if require else self.get
+        kwargs.setdefault('usedb', False)
         return get('rattail', 'appdir', **kwargs)
 
     def datadir(self, require=True):
@@ -579,11 +644,11 @@ class RattailConfig(object):
         if url is not None:
             return url.rstrip('/')
 
-    def datasync_url(self):
+    def datasync_url(self, **kwargs):
         """
         Returns configured URL for managing datasync daemon.
         """
-        return self.get('rattail.datasync', 'url')
+        return self.get('rattail.datasync', 'url', **kwargs)
 
     def get_enum(self, **kwargs):
         """
