@@ -60,6 +60,11 @@ class RattailWatcher(DataSyncWatcher):
         session = self.app.make_session(bind=self.engine)
         changes = session.query(model.Change).all()
         session.expunge_all()
+        # nb. fetch config flag while we have session open
+        deleted_first = self.config.getbool(
+            'rattail.datasync', 'rattail_watcher_deleted_first',
+            session=session,
+            default=False)
         session.close()
         if not changes:
             return
@@ -85,9 +90,6 @@ class RattailWatcher(DataSyncWatcher):
         # add new/dirty changes only, then we add deleted at the end.
         # so that deletes are processed last, by the consumer(s), to
         # hopefully avoid dependency issues
-        deleted_first = self.config.getbool(
-            'rattail.datasync', 'rattail_watcher_deleted_first',
-            default=False)
         if deleted_first:
             final = deleted + dirty
         else:
@@ -183,12 +185,13 @@ class RattailConsumer(DataSyncConsumer):
         self.model = self.get_data_model()
         self.topo_sortkey = make_topo_sortkey(self.model)
 
+    # TODO: deprecate / remove this
     def get_data_model(self):
         """
         Subclasses may override this if they have extended the schema.
         Defaults to ``rattail.db.model``.
         """
-        return model
+        return self.config.get_model()
 
     def process_changes(self, host_session, changes):
         """
