@@ -231,13 +231,13 @@ class EmailHandler(object):
         """
         if recipients is UNSPECIFIED:
             recips = set()
-            to = msg.get_all('To')
+            to = self.config.parse_list(msg['To'])
             if to:
                 recips = recips.union(set(to))
-            cc = msg.get_all('Cc')
+            cc = self.config.parse_list(msg['Cc'])
             if cc:
                 recips = recips.union(set(cc))
-            bcc = msg.get_all('Bcc')
+            bcc = self.config.parse_list(msg['Bcc'])
             if bcc:
                 recips = recips.union(set(bcc))
         else:
@@ -406,12 +406,27 @@ class Email(object):
 
         :rtype: str
         """
+        # first look for prefix specific to this email type
         prefix = self.config.get('rattail.mail', '{0}.prefix'.format(self.key))
         if not prefix:
+
+            # next look for global default prefix
             prefix = self.config.get('rattail.mail', 'default.prefix')
+            if not prefix:
+
+                # otherwise just use app node title
+                prefix = self.config.node_title()
+                if prefix:
+                    prefix = "[{}]".format(prefix)
+
+        # fall back to hard-coded default if no prefix yet
+        # TODO: not sure that's possible since we try node title above
         prefix = prefix or self.default_prefix
+
+        # force the [STAGE] prefix unless running in production
         if magic and not self.config.production():
             prefix = "[STAGE] {}".format(prefix)
+
         return prefix
 
     def get_default_subject(self, **data):
@@ -596,14 +611,11 @@ class Email(object):
         if not (to or cc or bcc):
             raise exceptions.RecipientsNotFound(self.key)
         if to:
-            for recip in to:
-                msg['To'] = recip
+            msg['To'] = ', '.join(to)
         if cc:
-            for recip in cc:
-                msg['Cc'] = recip
+            msg['Cc'] = ', '.join(cc)
         if bcc:
-            for recip in bcc:
-                msg['Bcc'] = recip
+            msg['Bcc'] = ', '.join(bcc)
 
 
 # NOTE: this bit of magic was stolen from Django
